@@ -16,17 +16,20 @@ Bio::Tradis - Bio-Tradis contains a set of tools to analyse the output from TraD
 
 =head1 VERSION
 
-version 1.132140
+version 1.132190
 
 =head1 SYNOPSIS
+
 Bio-Tradis provides functionality to:
-* detect TraDIS tags in a BAM file
-* add the tags to the reads
-* filter reads in a FastQ file containing a user defined tag
-* remove tags
-* map to a reference genome
-* create an insertion site plot file
-available as standalone scripts or as perl modules.
+=over
+=item * detect TraDIS tags in a BAM file - L<Bio::Tradis::DetectTags>
+=item * add the tags to the reads - L<Bio::Tradis::AddTagsToSeq>
+=item * filter reads in a FastQ file containing a user defined tag - L<Bio::Tradis::FilterTags>
+=item * remove tags - L<Bio::Tradis::RemoveTags>
+=item * map to a reference genome - L<Bio::Tradis::Map>
+=item * create an insertion site plot file - L<Bio::Tradis::TradisPlot>
+=back
+Most of these functions are available as standalone scripts or as perl modules.
 
 =head1 AUTHOR
 
