@@ -32,7 +32,7 @@ Bio::Tradis::DetectTags - Detect tr tags in BAM file
 
 =head1 VERSION
 
-version 1.132140
+version 1.132190
 
 =head1 SYNOPSIS
 
@@ -42,6 +42,20 @@ Detects presence of tr/tq tags in BAM files from Tradis analyses
    my $pipeline = Bio::Tradis::DetectTags->new(bamfile => 'abc');
    $pipeline->tags_present();
 
+=head1 NAME
+
+Bio::Tradis::DetectTags
+
+=head1 PARAMETERS
+
+=head2 Required
+
+C<bamfile> - path to/name of file to check
+
+=head1 METHODS
+
+C<tags_present> - returns true if TraDIS tags are detected in C<bamfile>
+
 =head1 AUTHOR
 
 Carla Cummins <cc21@sanger.ac.uk>
